django-hitcount
===============

.. image:: https://travis-ci.org/thornomad/django-hitcount.svg?branch=master
    :target: https://travis-ci.org/thornomad/django-hitcount
.. image:: https://coveralls.io/repos/thornomad/django-hitcount/badge.svg?branch=master
    :target: https://coveralls.io/r/thornomad/django-hitcount?branch=master
.. image:: https://badge.fury.io/py/django-hitcount.svg
    :target: http://badge.fury.io/py/django-hitcount
.. image:: https://requires.io/github/thornomad/django-hitcount/requirements.svg?branch=develop
     :target: https://requires.io/github/thornomad/django-hitcount/requirements/?branch=develop
     :alt: Requirements Status

Basic app that allows you to track the number of hits/views for a particular object.

Documentation:
--------------

`<http://django-hitcount.rtfd.org>`_

Source Code:
------------

`<https://github.com/thornomad/django-hitcount>`_

Issues
------

Use the GitHub `issue tracker`_ for django-hitcount to submit bugs, issues, and feature requests.

Changelog
---------

`<http://django-hitcount.readthedocs.org/en/latest/changelog.html>`_

.. _issue tracker: https://github.com/thornomad/django-hitcount/issues
